@@ -1,5 +1,7 @@
 /*
- * * Copyright (C) 2009 Ali <aliov@xfce.org>
+ * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -1580,7 +1582,7 @@ parole_gst_missing_codec_dialog(ParoleGst *gst, GstMessage *msg)
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 #if defined(__linux__)
                             GTK_MESSAGE_QUESTION,
-#elif defined(__FreeBSD__)
+#else
                             GTK_MESSAGE_WARNING,
 #endif
                             GTK_BUTTONS_NONE,
@@ -1588,24 +1590,23 @@ parole_gst_missing_codec_dialog(ParoleGst *gst, GstMessage *msg)
                             _("Additional software is required.")
                             ));
                             
-#if defined(__linux__)
     gtk_dialog_add_buttons( GTK_DIALOG(dialog), 
+#if defined(__linux__)
                             _("Don't Install"),
                             GTK_RESPONSE_REJECT,
                             _("Install"), 
                             GTK_RESPONSE_ACCEPT,
-                            NULL );
-#elif defined(__FreeBSD__)
-    gtk_dialog_add_button( GTK_DIALOG(dialog), 
-                            GTK_STOCK_OK,
-                            GTK_RESPONSE_ACCEPT);
+#else
+                            _("OK"),
+                            GTK_RESPONSE_ACCEPT,
 #endif
+                            NULL );
     
     gtk_message_dialog_format_secondary_markup(dialog,
 #if defined(__linux__)
                                              "Parole needs <b>%s</b> to play this file.\n"
                                              "It can be installed automatically.",
-#elif defined(__FreeBSD__)
+#else
                                              "Parole needs <b>%s</b> to play this file.",
 #endif
                                              desc);
