@@ -1,5 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -373,7 +375,7 @@ parole_pl_parser_parse_m3u (const gchar *filename)
         }
 
         else {
-	        pl_filename = g_strjoin("", path, lines[i], NULL);
+	        pl_filename = g_strjoin("/", path, lines[i], NULL);
         }
 	    
 	    list = g_slist_append (list, parole_file_new (pl_filename));
