@@ -1,5 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -73,7 +75,7 @@ void parole_about (GtkWindow *parent)
     "program-name", PACKAGE_NAME,
     "translator-credits", _("translator-credits"),
     "version", PACKAGE_VERSION,
-    "website", "http://goodies.xfce.org/projects/applications/parole",
+    "website", "http://docs.xfce.org/apps/parole/start",
     "website-label", _("Visit Parole website"),
     NULL);
 }
