@@ -1,5 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -407,6 +409,17 @@ parole_conf_dialog_set_defaults_playlist (ParoleConfDialog  *self, GtkBuilder *b
 		  NULL);
 		  
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), option);
+    
+     /**
+     * Remember playlist
+     **/
+    widget = GTK_WIDGET (gtk_builder_get_object (builder, "remember-playlist"));
+    
+    g_object_get (G_OBJECT (self->priv->conf),
+                  "remember-playlist", &option,
+                  NULL);
+          
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), option);
 }
 
 /* Load the multimedia-button default settings */
