@@ -1,5 +1,7 @@
 /*
  * * Copyright (C) 2009-2011 Ali <aliov@xfce.org>
+ * * Copyright (C) 2012-2013 Sean Davis <smd.seandavis@gmail.com>
+ * * Copyright (C) 2012-2013 Simon Steinbeiß <ochosi@xfce.org
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -258,31 +260,67 @@ parole_media_list_add (ParoleMediaList *list, ParoleFile *file, gboolean disc, g
     GtkTreeIter iter;
     gint nch;
     
+    /* Objects used for the remove-duplicates functionality. */
+    gchar *filename;
+    ParoleFile *row_file;
+    gboolean remove_duplicates;
+    g_object_get (G_OBJECT (list->priv->conf),
+                  "remove-duplicated", &remove_duplicates,
+                  NULL);
+    
+    /* Set the list_store variable based on with store we're viewing. */
     if (disc)
         list_store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (list->priv->disc_view)));
     else
         list_store = GTK_LIST_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (list->priv->view)));
+        
+    /* Remove duplicates functionality. If the file being added is already in the
+     * playlist, remove it from its current position in the playlist before
+     * adding it again. */
+    if (!disc && remove_duplicates && gtk_tree_model_iter_n_children (GTK_TREE_MODEL(list_store), NULL) != 0)
+    {
+        filename = g_strdup(parole_file_get_file_name(file));
+                
+        /* Check the first row */
+        gtk_tree_model_get_iter_first(GTK_TREE_MODEL(list_store), &iter);
+        gtk_tree_model_get(GTK_TREE_MODEL(list_store), &iter, DATA_COL, &row_file, -1);
+        if (g_strcmp0(filename, parole_file_get_file_name(row_file)) == 0)
+        {
+            gtk_list_store_remove (GTK_LIST_STORE(list_store), &iter);
+        }
+        
+        /* Check subsequent rows */
+        while (gtk_tree_model_iter_next(GTK_TREE_MODEL(list_store), &iter)) {
+            gtk_tree_model_get(GTK_TREE_MODEL(list_store), &iter, DATA_COL, &row_file, -1);
+            if (g_strcmp0(filename, parole_file_get_file_name(row_file)) == 0)
+            {
+                gtk_list_store_remove (GTK_LIST_STORE(list_store), &iter);
+            }
+        }
+        
+        g_object_unref(row_file);
+    }
     
+    /* Add the file to the playlist */
     gtk_list_store_append (list_store, &iter);
-    
     gtk_list_store_set (list_store, 
-			&iter, 
-			NAME_COL, parole_file_get_display_name (file),
-			DATA_COL, file,
-			LENGTH_COL, parole_taglibc_get_media_length (file),
-			PIXBUF_COL, NULL,
-			-1);
+                        &iter, 
+                        NAME_COL, parole_file_get_display_name (file),
+                        DATA_COL, file,
+                        LENGTH_COL, parole_taglibc_get_media_length (file),
+                        PIXBUF_COL, NULL,
+                        -1);
     
     if ( emit || select_row )
     {
-	path = gtk_tree_model_get_path (GTK_TREE_MODEL (list_store), &iter);
-	row = gtk_tree_row_reference_new (GTK_TREE_MODEL (list_store), path);
-	if ( select_row )
-	    parole_media_list_select_path (list, disc, path);
-	gtk_tree_path_free (path);
-	if ( emit )
-	    g_signal_emit (G_OBJECT (list), signals [MEDIA_ACTIVATED], 0, row);
-	gtk_tree_row_reference_free (row);
+        path = gtk_tree_model_get_path (GTK_TREE_MODEL (list_store), &iter);
+        row = gtk_tree_row_reference_new (GTK_TREE_MODEL (list_store), path);
+        if ( select_row )
+            parole_media_list_select_path (list, disc, path);
+        gtk_tree_path_free (path);
+        if ( emit )
+            g_signal_emit (G_OBJECT (list), signals [MEDIA_ACTIVATED], 0, row);
+        gtk_tree_row_reference_free (row);
     }
   
     /*
@@ -291,6 +329,7 @@ parole_media_list_add (ParoleMediaList *list, ParoleFile *file, gboolean disc, g
      */
     g_object_unref (file);
     
+    /* Update the playlist count. */    
     if (disc)
     nch = gtk_tree_model_iter_n_children (GTK_TREE_MODEL (list->priv->disc_store), NULL); 
     else
@@ -1175,9 +1214,19 @@ play_opened_files_activated_cb (GtkWidget *mi, ParoleConf *conf)
 static void
 remember_playlist_activated_cb (GtkWidget *mi, ParoleConf *conf)
 {
+    gchar *playlist_filename;
+    GFile *playlist_file;
     g_object_set (G_OBJECT (conf),
-		  "remember-playlist", gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)),
-		  NULL);
+                  "remember-playlist", gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi)),
+                  NULL);
+    if (!gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (mi))) {
+        playlist_filename = xfce_resource_save_location (XFCE_RESOURCE_DATA,
+                                                         PAROLE_AUTO_SAVED_PLAYLIST,
+                                                         FALSE);
+        playlist_file = g_file_new_for_path(playlist_filename);
+        g_file_delete(playlist_file, NULL, NULL);
+        g_free(playlist_filename);
+    }
 }
 
 static void
